@@ -1,9 +1,9 @@
 # coding=utf-8
 #
 # This file is part of Hypothesis, which may be found at
-# https://github.com/HypothesisWorks/hypothesis-python
+# https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2018 David R. MacIver
+# Most of this work is copyright (C) 2013-2019 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -11,51 +11,64 @@
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
-# obtain one at http://mozilla.org/MPL/2.0/.
+# obtain one at https://mozilla.org/MPL/2.0/.
 #
 # END HEADER
 
-from __future__ import division, print_function, absolute_import
+from __future__ import absolute_import, division, print_function
 
 from collections import defaultdict
+from random import choice as random_choice
 
 import hypothesis.internal.conjecture.utils as cu
-from hypothesis.errors import NoExamples, NoSuchExample, Unsatisfiable, \
-    UnsatisfiedAssumption
-from hypothesis.control import assume, _current_build_context
-from hypothesis._settings import Phase, note_deprecation
-from hypothesis.internal.compat import hrange, bit_length
+from hypothesis._settings import (
+    HealthCheck,
+    Phase,
+    Verbosity,
+    not_set,
+    note_deprecation,
+    settings,
+)
+from hypothesis.control import _current_build_context, assume
+from hypothesis.errors import HypothesisException, UnsatisfiedAssumption
+from hypothesis.internal.compat import bit_length, hrange
+from hypothesis.internal.conjecture.utils import (
+    LABEL_MASK,
+    calc_label_from_cls,
+    calc_label_from_name,
+    combine_labels,
+)
 from hypothesis.internal.coverage import check_function
-from hypothesis.utils.conventions import UniqueIdentifier
 from hypothesis.internal.lazyformat import lazyformat
 from hypothesis.internal.reflection import get_pretty_function_description
 from hypothesis.internal.validation import check_type
-from hypothesis.internal.conjecture.utils import LABEL_MASK, \
-    combine_labels, calc_label_from_cls, calc_label_from_name
+from hypothesis.utils.conventions import UniqueIdentifier
 
 try:
-    from random import Random  # noqa
     from typing import List, Callable, TypeVar, Generic, Optional  # noqa
-    Ex = TypeVar('Ex', covariant=True)
-    T = TypeVar('T')
 
+    Ex = TypeVar("Ex", covariant=True)
+    T = TypeVar("T")
+
+    from hypothesis._settings import UniqueIdentifier  # noqa
     from hypothesis.internal.conjecture.data import ConjectureData  # noqa
 
 except ImportError:  # pragma: no cover
-    Ex = 'key'  # type: ignore
+    Ex = "key"  # type: ignore
     Generic = {Ex: object}  # type: ignore
 
-calculating = UniqueIdentifier('calculating')
+calculating = UniqueIdentifier("calculating")
 
 MAPPED_SEARCH_STRATEGY_DO_DRAW_LABEL = calc_label_from_name(
-    'another attempted draw in MappedSearchStrategy')
+    "another attempted draw in MappedSearchStrategy"
+)
 
 
 def one_of_strategies(xs):
     """Helper function for unioning multiple strategies."""
     xs = tuple(xs)
     if not xs:
-        raise ValueError('Cannot join an empty list of strategies')
+        raise ValueError("Cannot join an empty list of strategies")
     return OneOfStrategy(xs)
 
 
@@ -99,9 +112,9 @@ class SearchStrategy(Generic[Ex]):
         and performance of parsing with derivatives." ACM SIGPLAN Notices 51.6
         (2016): 224-236.
         """
-        cache_key = 'cached_' + name
-        calculation = 'calc_' + name
-        force_key = 'force_' + name
+        cache_key = "cached_" + name
+        calculation = "calc_" + name
+        force_key = "force_" + name
 
         def forced_value(target):
             try:
@@ -116,6 +129,7 @@ class SearchStrategy(Generic[Ex]):
                 pass
 
             mapping = {}
+            sentinel = object()
             hit_recursion = [False]
 
             # For a first pass we do a direct recursive calculation of the
@@ -127,17 +141,15 @@ class SearchStrategy(Generic[Ex]):
                     return forced_value(strat)
                 except AttributeError:
                     pass
-                try:
-                    result = mapping[strat]
-                    if result is calculating:
-                        hit_recursion[0] = True
-                        return default
-                    else:
-                        return result
-                except KeyError:
+                result = mapping.get(strat, sentinel)
+                if result is calculating:
+                    hit_recursion[0] = True
+                    return default
+                elif result is sentinel:
                     mapping[strat] = calculating
                     mapping[strat] = getattr(strat, calculation)(recur)
                     return mapping[strat]
+                return result
 
             recur(self)
 
@@ -166,12 +178,13 @@ class SearchStrategy(Generic[Ex]):
                     except AttributeError:
                         pass
                     listeners[other].add(strat)
-                    try:
-                        return mapping[other]
-                    except KeyError:
+                    result = mapping.get(other, sentinel)
+                    if result is sentinel:
                         needs_update.add(other)
                         mapping[other] = default
                         return default
+                    return result
+
                 return recur_inner
 
             count = 0
@@ -217,14 +230,14 @@ class SearchStrategy(Generic[Ex]):
     # The fact that this returns False does not guarantee that a valid value
     # can be drawn - this is not intended to be perfect, and is primarily
     # intended to be an optimisation for some cases.
-    is_empty = recursive_property('is_empty', True)
+    is_empty = recursive_property("is_empty", True)
 
     # Returns True if values from this strategy can safely be reused without
     # this causing unexpected behaviour.
-    has_reusable_values = recursive_property('has_reusable_values', True)
+    has_reusable_values = recursive_property("has_reusable_values", True)
 
     # Whether this strategy is suitable for holding onto in a cache.
-    is_cacheable = recursive_property('is_cacheable', True)
+    is_cacheable = recursive_property("is_cacheable", True)
 
     def calc_is_cacheable(self, recur):
         return True
@@ -241,8 +254,8 @@ class SearchStrategy(Generic[Ex]):
     def calc_has_reusable_values(self, recur):
         return False
 
-    def example(self, random=None):
-        # type: (Random) -> Ex
+    def example(self, random=not_set):
+        # type: (UniqueIdentifier) -> Ex
         """Provide an example of the sort of value that this strategy
         generates. This is biased to be slightly simpler than is typical for
         values from this strategy, for clarity purposes.
@@ -252,66 +265,49 @@ class SearchStrategy(Generic[Ex]):
 
         This method is part of the public API.
         """
+        if random is not not_set:
+            note_deprecation("The random argument does nothing", since="2019-07-08")
+
         context = _current_build_context.value
         if context is not None:
             if context.data is not None and context.data.depth > 0:
-                note_deprecation(
-                    'Using example() inside a strategy definition is a bad '
-                    'idea. It will become an error in a future version of '
-                    "Hypothesis, but it's unlikely that it's doing what you "
-                    'intend even now. Instead consider using '
-                    'hypothesis.strategies.builds() or '
-                    '@hypothesis.strategies.composite to define your strategy.'
-                    ' See '
-                    'https://hypothesis.readthedocs.io/en/latest/data.html'
-                    '#hypothesis.strategies.builds or '
-                    'https://hypothesis.readthedocs.io/en/latest/data.html'
-                    '#composite-strategies for more details.'
+                raise HypothesisException(
+                    "Using example() inside a strategy definition is a bad "
+                    "idea. Instead consider using hypothesis.strategies.builds() "
+                    "or @hypothesis.strategies.composite to define your strategy."
+                    " See https://hypothesis.readthedocs.io/en/latest/data.html"
+                    "#hypothesis.strategies.builds or "
+                    "https://hypothesis.readthedocs.io/en/latest/data.html"
+                    "#composite-strategies for more details."
                 )
             else:
-                note_deprecation(
-                    'Using example() inside a test function is a bad '
-                    'idea. It will become an error in a future version of '
-                    "Hypothesis, but it's unlikely that it's doing what you "
-                    'intend even now. Instead consider using '
-                    'hypothesis.strategies.data() to draw '
-                    'more examples during testing. See '
-                    'https://hypothesis.readthedocs.io/en/latest/data.html'
-                    '#drawing-interactively-in-tests for more details.'
+                raise HypothesisException(
+                    "Using example() inside a test function is a bad "
+                    "idea. Instead consider using hypothesis.strategies.data() "
+                    "to draw more examples during testing. See "
+                    "https://hypothesis.readthedocs.io/en/latest/data.html"
+                    "#drawing-interactively-in-tests for more details."
                 )
 
-        from hypothesis import find, settings, Verbosity
+        from hypothesis.core import given
 
-        # Conjecture will always try the zero example first. This would result
-        # in us producing the same example each time, which is boring, so we
-        # deliberately skip the first example it feeds us.
-        first = []  # type: list
+        # Note: this function has a weird name because it might appear in
+        # tracebacks, and we want users to know that they can ignore it.
+        @given(self)
+        @settings(
+            database=None,
+            max_examples=10,
+            deadline=None,
+            verbosity=Verbosity.quiet,
+            phases=(Phase.generate,),
+            suppress_health_check=HealthCheck.all(),
+        )
+        def example_generating_inner_function(ex):
+            examples.append(ex)
 
-        def condition(x):
-            if first:
-                return True
-            else:
-                first.append(x)
-                return False
-        try:
-            return find(
-                self,
-                condition,
-                random=random,
-                settings=settings(
-                    database=None,
-                    verbosity=Verbosity.quiet,
-                    phases=tuple(set(Phase) - {Phase.shrink}),
-                )
-            )
-        except (NoSuchExample, Unsatisfiable):
-            # This can happen when a strategy has only one example. e.g.
-            # st.just(x). In that case we wanted the first example after all.
-            if first:
-                return first[0]
-            raise NoExamples(
-                u'Could not find any valid examples in 100 tries'
-            )
+        examples = []  # type: List[Ex]
+        example_generating_inner_function()
+        return random_choice(examples)
 
     def map(self, pack):
         # type: (Callable[[Ex], T]) -> SearchStrategy[T]
@@ -320,9 +316,7 @@ class SearchStrategy(Generic[Ex]):
 
         This method is part of the public API.
         """
-        return MappedSearchStrategy(
-            pack=pack, strategy=self
-        )
+        return MappedSearchStrategy(pack=pack, strategy=self)
 
     def flatmap(self, expand):
         # type: (Callable[[Ex], SearchStrategy[T]]) -> SearchStrategy[T]
@@ -333,9 +327,8 @@ class SearchStrategy(Generic[Ex]):
         This method is part of the public API.
         """
         from hypothesis.searchstrategy.flatmapped import FlatMapStrategy
-        return FlatMapStrategy(
-            expand=expand, strategy=self
-        )
+
+        return FlatMapStrategy(expand=expand, strategy=self)
 
     def filter(self, condition):
         # type: (Callable[[Ex], bool]) -> SearchStrategy[Ex]
@@ -346,10 +339,13 @@ class SearchStrategy(Generic[Ex]):
 
         This method is part of the public API.
         """
-        return FilteredStrategy(
-            condition=condition,
-            strategy=self,
-        )
+        return FilteredStrategy(conditions=(condition,), strategy=self)
+
+    def do_filtered_draw(self, data, filter_strategy):
+        # Hook for strategies that want to override the behaviour of
+        # FilteredStrategy. Most strategies don't, so by default we delegate
+        # straight back to the default filtered-draw implementation.
+        return filter_strategy.default_do_filtered_draw(data)
 
     @property
     def branches(self):
@@ -363,7 +359,7 @@ class SearchStrategy(Generic[Ex]):
         This method is part of the public API.
         """
         if not isinstance(other, SearchStrategy):
-            raise ValueError('Cannot | a SearchStrategy with %r' % (other,))
+            raise ValueError("Cannot | a SearchStrategy with %r" % (other,))
         return one_of_strategies((self, other))
 
     def validate(self):
@@ -413,7 +409,7 @@ class SearchStrategy(Generic[Ex]):
 
     def do_draw(self, data):
         # type: (ConjectureData) -> Ex
-        raise NotImplementedError('%s.do_draw' % (type(self).__name__,))
+        raise NotImplementedError("%s.do_draw" % (type(self).__name__,))
 
     def __init__(self):
         pass
@@ -428,19 +424,12 @@ class OneOfStrategy(SearchStrategy):
     conditional distribution of that strategy.
     """
 
-    def __init__(self, strategies, bias=None):
+    def __init__(self, strategies):
         SearchStrategy.__init__(self)
         strategies = tuple(strategies)
         self.original_strategies = list(strategies)
         self.__element_strategies = None
-        self.bias = bias
         self.__in_branches = False
-        if bias is not None:
-            assert 0 < bias < 1
-            self.sampler = cu.Sampler(
-                [bias ** i for i in range(len(strategies))])
-        else:
-            self.sampler = None
 
     def calc_is_empty(self, recur):
         return all(recur(e) for e in self.original_strategies)
@@ -458,8 +447,7 @@ class OneOfStrategy(SearchStrategy):
             for arg in self.original_strategies:
                 check_strategy(arg)
                 if not arg.is_empty:
-                    strategies.extend(
-                        [s for s in arg.branches if not s.is_empty])
+                    strategies.extend([s for s in arg.branches if not s.is_empty])
             pruned = []
             seen = set()
             for s in strategies:
@@ -473,7 +461,8 @@ class OneOfStrategy(SearchStrategy):
             shift = bit_length(len(pruned))
             for i, p in enumerate(pruned):
                 branch_labels.append(
-                    (((self.label ^ p.label) << shift) + i) & LABEL_MASK)
+                    (((self.label ^ p.label) << shift) + i) & LABEL_MASK
+                )
             self.__element_strategies = pruned
             self.__branch_labels = tuple(branch_labels)
         return self.__element_strategies
@@ -481,12 +470,13 @@ class OneOfStrategy(SearchStrategy):
     @property
     def branch_labels(self):
         self.element_strategies
+        assert len(self.__branch_labels) == len(self.element_strategies)
         return self.__branch_labels
 
     def calc_label(self):
-        return combine_labels(self.class_label, *[
-            p.label for p in self.original_strategies
-        ])
+        return combine_labels(
+            self.class_label, *[p.label for p in self.original_strategies]
+        )
 
     def do_draw(self, data):
         # type: (ConjectureData) -> Ex
@@ -495,16 +485,12 @@ class OneOfStrategy(SearchStrategy):
         if n == 1:
             return data.draw(self.element_strategies[0])
 
-        if self.sampler is None:
-            i = cu.integer_range(data, 0, n - 1)
-        else:
-            i = self.sampler.sample(data)
+        i = cu.integer_range(data, 0, n - 1)
 
-        return data.draw(
-            self.element_strategies[i], label=self.branch_labels[i])
+        return data.draw(self.element_strategies[i], label=self.branch_labels[i])
 
     def __repr__(self):
-        return 'one_of(%s)' % ', '.join(map(repr, self.original_strategies))
+        return "one_of(%s)" % ", ".join(map(repr, self.original_strategies))
 
     def do_validate(self):
         for e in self.element_strategies:
@@ -512,7 +498,7 @@ class OneOfStrategy(SearchStrategy):
 
     @property
     def branches(self):
-        if self.bias is None and not self.__in_branches:
+        if not self.__in_branches:
             try:
                 self.__in_branches = True
                 return self.element_strategies
@@ -542,21 +528,20 @@ class MappedSearchStrategy(SearchStrategy):
         return recur(self.mapped_strategy)
 
     def __repr__(self):
-        if not hasattr(self, '_cached_repr'):
-            self._cached_repr = '%r.map(%s)' % (
-                self.mapped_strategy, get_pretty_function_description(
-                    self.pack)
+        if not hasattr(self, "_cached_repr"):
+            self._cached_repr = "%r.map(%s)" % (
+                self.mapped_strategy,
+                get_pretty_function_description(self.pack),
             )
         return self._cached_repr
 
     def do_validate(self):
         self.mapped_strategy.validate()
 
-    def pack(self, x):  # type: ignore
+    def pack(self, x):
         """Take a value produced by the underlying mapped_strategy and turn it
         into a value suitable for outputting from this strategy."""
-        raise NotImplementedError(
-            '%s.pack()' % (self.__class__.__name__))
+        raise NotImplementedError("%s.pack()" % (self.__class__.__name__))
 
     def do_draw(self, data):
         # type: (ConjectureData) -> Ex
@@ -582,12 +567,26 @@ class MappedSearchStrategy(SearchStrategy):
         ]
 
 
-class FilteredStrategy(SearchStrategy):
+filter_not_satisfied = UniqueIdentifier("filter not satisfied")
 
-    def __init__(self, strategy, condition):
+
+class FilteredStrategy(SearchStrategy):
+    def __init__(self, strategy, conditions):
         super(FilteredStrategy, self).__init__()
-        self.condition = condition
-        self.filtered_strategy = strategy
+        if isinstance(strategy, FilteredStrategy):
+            # Flatten chained filters into a single filter with multiple
+            # conditions.
+            self.flat_conditions = strategy.flat_conditions + conditions
+            self.filtered_strategy = strategy.filtered_strategy
+        else:
+            self.flat_conditions = conditions
+            self.filtered_strategy = strategy
+
+        assert self.flat_conditions
+        assert isinstance(self.flat_conditions, tuple)
+        assert not isinstance(self.filtered_strategy, FilteredStrategy)
+
+        self.__condition = None
 
     def calc_is_empty(self, recur):
         return recur(self.filtered_strategy)
@@ -596,18 +595,49 @@ class FilteredStrategy(SearchStrategy):
         return recur(self.filtered_strategy)
 
     def __repr__(self):
-        if not hasattr(self, '_cached_repr'):
-            self._cached_repr = '%r.filter(%s)' % (
-                self.filtered_strategy, get_pretty_function_description(
-                    self.condition)
+        if not hasattr(self, "_cached_repr"):
+            self._cached_repr = "%r%s" % (
+                self.filtered_strategy,
+                "".join(
+                    ".filter(%s)" % get_pretty_function_description(cond)
+                    for cond in self.flat_conditions
+                ),
             )
         return self._cached_repr
 
     def do_validate(self):
         self.filtered_strategy.validate()
 
+    @property
+    def condition(self):
+        if self.__condition is None:
+            assert self.flat_conditions
+            if len(self.flat_conditions) == 1:
+                # Avoid an extra indirection in the common case of only one
+                # condition.
+                self.__condition = self.flat_conditions[0]
+            else:
+                self.__condition = lambda x: all(
+                    cond(x) for cond in self.flat_conditions
+                )
+        return self.__condition
+
     def do_draw(self, data):
         # type: (ConjectureData) -> Ex
+        result = self.filtered_strategy.do_filtered_draw(
+            data=data, filter_strategy=self
+        )
+        if result is not filter_not_satisfied:
+            return result
+
+        data.note_event("Aborted test because unable to satisfy %r" % (self,))
+        data.mark_invalid()
+        raise AssertionError("Unreachable, for Mypy")  # pragma: no cover
+
+    def note_retried(self, data):
+        data.note_event(lazyformat("Retried draw from %r to satisfy filter", self))
+
+    def default_do_filtered_draw(self, data):
         for i in hrange(3):
             start_index = data.index
             value = data.draw(self.filtered_strategy)
@@ -615,27 +645,23 @@ class FilteredStrategy(SearchStrategy):
                 return value
             else:
                 if i == 0:
-                    data.note_event(lazyformat(
-                        'Retried draw from %r to satisfy filter', self,))
+                    self.note_retried(data)
                 # This is to guard against the case where we consume no data.
                 # As long as we consume data, we'll eventually pass or raise.
                 # But if we don't this could be an infinite loop.
                 assume(data.index > start_index)
-        data.note_event('Aborted test because unable to satisfy %r' % (
-            self,
-        ))
-        data.mark_invalid()
-        raise AssertionError('Unreachable, for Mypy')  # pragma: no cover
+
+        return filter_not_satisfied
 
     @property
     def branches(self):
         # type: () -> List[SearchStrategy[Ex]]
         return [
-            FilteredStrategy(strategy=strategy, condition=self.condition)
+            FilteredStrategy(strategy=strategy, conditions=self.flat_conditions)
             for strategy in self.filtered_strategy.branches
         ]
 
 
 @check_function
-def check_strategy(arg, name=''):
+def check_strategy(arg, name=""):
     check_type(SearchStrategy, arg, name)
