@@ -1,9 +1,9 @@
 # coding=utf-8
 #
 # This file is part of Hypothesis, which may be found at
-# https://github.com/HypothesisWorks/hypothesis-python
+# https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2018 David R. MacIver
+# Most of this work is copyright (C) 2013-2019 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -11,28 +11,26 @@
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
-# obtain one at http://mozilla.org/MPL/2.0/.
+# obtain one at https://mozilla.org/MPL/2.0/.
 #
 # END HEADER
 
-from __future__ import division, print_function, absolute_import
+from __future__ import absolute_import, division, print_function
 
 import pytest
-from flaky import flaky
 
 import hypothesis.strategies as st
-from hypothesis import given, assume
+from hypothesis import assume, given
 from hypothesis.errors import InvalidArgument
-from tests.common.debug import minimal
 from hypothesis.internal.compat import hrange
+from tests.common.debug import minimal
+from tests.common.utils import flaky
 
 
 @st.composite
 def badly_draw_lists(draw, m=0):
     length = draw(st.integers(m, m + 10))
-    return [
-        draw(st.integers()) for _ in hrange(length)
-    ]
+    return [draw(st.integers()) for _ in hrange(length)]
 
 
 def test_simplify_draws():
@@ -58,13 +56,14 @@ def test_can_assume_in_draw(xy):
 
 
 def test_uses_definitions_for_reprs():
-    assert repr(badly_draw_lists()) == 'badly_draw_lists()'
-    assert repr(badly_draw_lists(1)) == 'badly_draw_lists(m=1)'
-    assert repr(badly_draw_lists(m=1)) == 'badly_draw_lists(m=1)'
+    assert repr(badly_draw_lists()) == "badly_draw_lists()"
+    assert repr(badly_draw_lists(1)) == "badly_draw_lists(m=1)"
+    assert repr(badly_draw_lists(m=1)) == "badly_draw_lists(m=1)"
 
 
 def test_errors_given_default_for_draw():
     with pytest.raises(InvalidArgument):
+
         @st.composite
         def foo(x=None):
             pass
@@ -72,6 +71,7 @@ def test_errors_given_default_for_draw():
 
 def test_errors_given_function_of_no_arguments():
     with pytest.raises(InvalidArgument):
+
         @st.composite
         def foo():
             pass
@@ -79,6 +79,7 @@ def test_errors_given_function_of_no_arguments():
 
 def test_errors_given_kwargs_only():
     with pytest.raises(InvalidArgument):
+
         @st.composite
         def foo(**kwargs):
             pass
@@ -88,6 +89,7 @@ def test_can_use_pure_args():
     @st.composite
     def stuff(*args):
         return args[0](st.sampled_from(args[1:]))
+
     assert minimal(stuff(1, 2, 3, 4, 5), lambda x: True) == 1
 
 
@@ -99,15 +101,14 @@ def test_composite_of_lists():
     assert minimal(st.lists(f()), lambda x: len(x) >= 10) == [0] * 10
 
 
-@flaky(min_passes=3, max_runs=5)
+@flaky(min_passes=2, max_runs=5)
 def test_can_shrink_matrices_with_length_param():
     @st.composite
     def matrix(draw):
         rows = draw(st.integers(1, 10))
         columns = draw(st.integers(1, 10))
         return [
-            [draw(st.integers(0, 10000)) for _ in range(columns)]
-            for _ in range(rows)
+            [draw(st.integers(0, 10000)) for _ in range(columns)] for _ in range(rows)
         ]
 
     def transpose(m):
