@@ -1,9 +1,9 @@
 # coding=utf-8
 #
 # This file is part of Hypothesis, which may be found at
-# https://github.com/HypothesisWorks/hypothesis-python
+# https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2018 David R. MacIver
+# Most of this work is copyright (C) 2013-2019 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -11,20 +11,19 @@
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
-# obtain one at http://mozilla.org/MPL/2.0/.
+# obtain one at https://mozilla.org/MPL/2.0/.
 #
 # END HEADER
 
-from __future__ import division, print_function, absolute_import
+from __future__ import absolute_import, division, print_function
 
 import pytest
 
-from hypothesis import Verbosity, HealthCheck, given, assume, reject, \
-    example, settings
+from hypothesis import HealthCheck, Verbosity, assume, example, given, reject, settings
 from hypothesis.errors import Flaky, Unsatisfiable, UnsatisfiedAssumption
+from hypothesis.internal.conjecture.engine import MIN_TEST_CALLS
+from hypothesis.strategies import booleans, composite, integers, lists, random_module
 from tests.common.utils import no_shrink
-from hypothesis.strategies import lists, booleans, integers, composite, \
-    random_module
 
 
 class Nope(Exception):
@@ -61,13 +60,20 @@ def test_gives_flaky_error_if_assumption_is_flaky():
 def test_does_not_attempt_to_shrink_flaky_errors():
     values = []
 
+    @settings(database=None)
     @given(integers())
     def test(x):
         values.append(x)
         assert len(values) != 1
+
     with pytest.raises(Flaky):
         test()
-    assert len(set(values)) == 1
+    # We try a total of ten calls in the generation phase, each usually a
+    # unique value, looking briefly (and unsuccessfully) for another bug.
+    assert 1 < len(set(values)) <= MIN_TEST_CALLS
+    # We don't try any new values while shrinking, just execute the test
+    # twice more (to check for flakiness and to raise the bug to the user).
+    assert set(values) == set(values[:-2])
 
 
 class SatisfyMe(Exception):
@@ -82,14 +88,12 @@ def single_bool_lists(draw):
     return result
 
 
-@example([True, False, False, False], [3], None,)
-@example([False, True, False, False], [3], None,)
-@example([False, False, True, False], [3], None,)
-@example([False, False, False, True], [3], None,)
-@settings(max_examples=0)
-@given(
-    lists(booleans()) | single_bool_lists(),
-    lists(integers(1, 3)), random_module())
+@example([True, False, False, False], [3], None)
+@example([False, True, False, False], [3], None)
+@example([False, False, True, False], [3], None)
+@example([False, False, False, True], [3], None)
+@settings(deadline=None)
+@given(lists(booleans()) | single_bool_lists(), lists(integers(1, 3)), random_module())
 def test_failure_sequence_inducing(building, testing, rnd):
     buildit = iter(building)
     testit = iter(testing)
@@ -103,8 +107,10 @@ def test_failure_sequence_inducing(building, testing, rnd):
 
     @given(integers().map(build))
     @settings(
-        verbosity=Verbosity.quiet, database=None,
-        suppress_health_check=HealthCheck.all(), phases=no_shrink
+        verbosity=Verbosity.quiet,
+        database=None,
+        suppress_health_check=HealthCheck.all(),
+        phases=no_shrink,
     )
     def test(x):
         try:
