@@ -1,9 +1,9 @@
 # coding=utf-8
 #
 # This file is part of Hypothesis, which may be found at
-# https://github.com/HypothesisWorks/hypothesis-python
+# https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2018 David R. MacIver
+# Most of this work is copyright (C) 2013-2019 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -11,7 +11,7 @@
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
-# obtain one at http://mozilla.org/MPL/2.0/.
+# obtain one at https://mozilla.org/MPL/2.0/.
 #
 # END HEADER
 
@@ -56,25 +56,26 @@ ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 """
 
-from __future__ import division, print_function, absolute_import
+from __future__ import absolute_import, division, print_function
 
 import re
-from collections import deque, defaultdict
+from collections import defaultdict, deque
 
 import pytest
 
+from hypothesis.internal.compat import PY3, PYPY, Counter, OrderedDict, a_good_encoding
 from hypothesis.vendor import pretty
 from tests.common.utils import capture_out
-from hypothesis.internal.compat import PY3, Counter, OrderedDict, \
-    a_good_encoding
 
-py2_only = pytest.mark.skipif(PY3, reason='This test only runs on python 2')
+py2_only = pytest.mark.skipif(PY3, reason="This test only runs on python 2")
 
 if PY3:
     from io import StringIO
 
     def unicode_to_str(x, encoding=None):
         return x
+
+
 else:
     from StringIO import StringIO
 
@@ -99,47 +100,43 @@ def skip_without(mod):
         __import__(mod)
         return lambda f: f
     except ImportError:
-        return pytest.mark.skipif(True, reason='Missing %s' % (mod,))
+        return pytest.mark.skipif(True, reason="Missing %s" % (mod,))
 
 
 assert_raises = pytest.raises
 
 
 class MyList(object):
-
     def __init__(self, content):
         self.content = content
 
     def _repr_pretty_(self, p, cycle):
         if cycle:
-            p.text('MyList(...)')
+            p.text("MyList(...)")
         else:
-            with p.group(3, 'MyList(', ')'):
+            with p.group(3, "MyList(", ")"):
                 for (i, child) in enumerate(self.content):
                     if i:
-                        p.text(',')
+                        p.text(",")
                         p.breakable()
                     else:
-                        p.breakable('')
+                        p.breakable("")
                     p.pretty(child)
 
 
 class MyDict(dict):
-
     def _repr_pretty_(self, p, cycle):
-        p.text('MyDict(...)')
+        p.text("MyDict(...)")
 
 
 class MyObj(object):
-
     def somemethod(self):
         pass
 
 
 class Dummy1(object):
-
     def _repr_pretty_(self, p, cycle):
-        p.text('Dummy1(...)')
+        p.text("Dummy1(...)")
 
 
 class Dummy2(Dummy1):
@@ -154,85 +151,77 @@ NoModule.__module__ = None
 
 
 class Breaking(object):
-
     def _repr_pretty_(self, p, cycle):
-        with p.group(4, 'TG: ', ':'):
-            p.text('Breaking(')
+        with p.group(4, "TG: ", ":"):
+            p.text("Breaking(")
             p.break_()
-            p.text(')')
+            p.text(")")
 
 
 class BreakingRepr(object):
-
     def __repr__(self):
-        return 'Breaking(\n)'
+        return "Breaking(\n)"
 
 
 class BreakingReprParent(object):
-
     def _repr_pretty_(self, p, cycle):
-        with p.group(4, 'TG: ', ':'):
+        with p.group(4, "TG: ", ":"):
             p.pretty(BreakingRepr())
 
 
 class BadRepr(object):
-
     def __repr__(self):
         return 1 / 0
 
 
 def test_list():
-    assert pretty.pretty([]) == '[]'
-    assert pretty.pretty([1]) == '[1]'
+    assert pretty.pretty([]) == "[]"
+    assert pretty.pretty([1]) == "[1]"
 
 
 def test_dict():
-    assert pretty.pretty({}) == '{}'
-    assert pretty.pretty({1: 1}) == '{1: 1}'
+    assert pretty.pretty({}) == "{}"
+    assert pretty.pretty({1: 1}) == "{1: 1}"
 
 
 def test_tuple():
-    assert pretty.pretty(()) == '()'
-    assert pretty.pretty((1,)) == '(1,)'
-    assert pretty.pretty((1, 2)) == '(1, 2)'
+    assert pretty.pretty(()) == "()"
+    assert pretty.pretty((1,)) == "(1,)"
+    assert pretty.pretty((1, 2)) == "(1, 2)"
 
 
 class ReprDict(dict):
-
     def __repr__(self):
-        return 'hi'
+        return "hi"
 
 
 def test_dict_with_custom_repr():
-    assert pretty.pretty(ReprDict()) == 'hi'
+    assert pretty.pretty(ReprDict()) == "hi"
 
 
 class ReprList(list):
-
     def __repr__(self):
-        return 'bye'
+        return "bye"
 
 
 class ReprSet(set):
-
     def __repr__(self):
-        return 'cat'
+        return "cat"
 
 
 def test_set_with_custom_repr():
-    assert pretty.pretty(ReprSet()) == 'cat'
+    assert pretty.pretty(ReprSet()) == "cat"
 
 
 def test_list_with_custom_repr():
-    assert pretty.pretty(ReprList()) == 'bye'
+    assert pretty.pretty(ReprList()) == "bye"
 
 
 def test_indentation():
     """Test correct indentation in groups."""
     count = 40
     gotoutput = pretty.pretty(MyList(range(count)))
-    expectedoutput = 'MyList(\n' + ',\n'.join('   %d' %
-                                              i for i in range(count)) + ')'
+    expectedoutput = "MyList(\n" + ",\n".join("   %d" % i for i in range(count)) + ")"
 
     assert_equal(gotoutput, expectedoutput)
 
@@ -241,7 +230,7 @@ def test_dispatch():
     """Test correct dispatching: The _repr_pretty_ method for MyDict must be
     found before the registered printer for dict."""
     gotoutput = pretty.pretty(MyDict())
-    expectedoutput = 'MyDict(...)'
+    expectedoutput = "MyDict(...)"
 
     assert_equal(gotoutput, expectedoutput)
 
@@ -250,61 +239,76 @@ def test_callability_checking():
     """Test that the _repr_pretty_ method is tested for callability and skipped
     if not."""
     gotoutput = pretty.pretty(Dummy2())
-    expectedoutput = 'Dummy1(...)'
+    expectedoutput = "Dummy1(...)"
 
     assert_equal(gotoutput, expectedoutput)
 
 
 def test_sets():
     """Test that set and frozenset use Python 3 formatting."""
-    objects = [set(), frozenset(), set([1]), frozenset([1]), set([1, 2]),
-               frozenset([1, 2]), set([-1, -2, -3])]
-    expected = ['set()', 'frozenset()', '{1}', 'frozenset({1})', '{1, 2}',
-                'frozenset({1, 2})', '{-3, -2, -1}']
+    objects = [
+        set(),
+        frozenset(),
+        {1},
+        frozenset([1]),
+        {1, 2},
+        frozenset([1, 2]),
+        {-1, -2, -3},
+    ]
+    expected = [
+        "set()",
+        "frozenset()",
+        "{1}",
+        "frozenset({1})",
+        "{1, 2}",
+        "frozenset({1, 2})",
+        "{-3, -2, -1}",
+    ]
     for obj, expected_output in zip(objects, expected):
         got_output = pretty.pretty(obj)
         assert_equal(got_output, expected_output)
 
 
 def test_unsortable_set():
-    xs = set([1, 2, 3, 'foo', 'bar', 'baz', object()])
+    xs = {1, 2, 3, "foo", "bar", "baz", object()}
     p = pretty.pretty(xs)
     for x in xs:
         assert pretty.pretty(x) in p
 
 
 def test_unsortable_dict():
-    xs = dict((k, 1) for k in [1, 2, 3, 'foo', 'bar', 'baz', object()])
+    xs = {k: 1 for k in [1, 2, 3, "foo", "bar", "baz", object()]}
     p = pretty.pretty(xs)
     for x in xs:
         assert pretty.pretty(x) in p
 
 
-@skip_without('xxlimited')
+@skip_without("xxlimited")
 def test_pprint_heap_allocated_type():
     """Test that pprint works for heap allocated types."""
     import xxlimited
+
     output = pretty.pretty(xxlimited.Null)
-    assert_equal(output, 'xxlimited.Null')
+    assert_equal(output, "xxlimited.Null")
 
 
 def test_pprint_nomod():
     """Test that pprint works for classes with no __module__."""
     output = pretty.pretty(NoModule)
-    assert_equal(output, 'NoModule')
+    assert_equal(output, "NoModule")
 
 
 def test_pprint_break():
     """Test that p.break_ produces expected output."""
     output = pretty.pretty(Breaking())
-    expected = 'TG: Breaking(\n    ):'
+    expected = "TG: Breaking(\n    ):"
     assert_equal(output, expected)
 
 
 def test_pprint_break_repr():
     """Test that p.break_ is used in repr."""
     output = pretty.pretty(BreakingReprParent())
-    expected = 'TG: Breaking(\n    ):'
+    expected = "TG: Breaking(\n    ):"
     assert_equal(output, expected)
 
 
@@ -315,7 +319,6 @@ def test_bad_repr():
 
 
 class BadException(Exception):
-
     def __str__(self):
         return -1
 
@@ -325,7 +328,7 @@ class ReallyBadRepr(object):
 
     @property
     def __class__(self):
-        raise ValueError('I am horrible')
+        raise ValueError("I am horrible")
 
     def __repr__(self):
         raise BadException()
@@ -349,12 +352,15 @@ try:
 
     def test_super_repr():
         output = pretty.pretty(super(SA))
-        assert_in('SA', output)
+        assert_in("SA", output)
 
         sb = SB()
         output = pretty.pretty(super(SA, sb))
-        assert_in('SA', output)
+        assert_in("SA", output)
+
+
 except AttributeError:
+
     def test_super_repr():
         pretty.pretty(super(SA))
         sb = SB()
@@ -364,51 +370,50 @@ except AttributeError:
 def test_long_list():
     lis = list(range(10000))
     p = pretty.pretty(lis)
-    last2 = p.rsplit('\n', 2)[-2:]
-    assert_equal(last2, [' 999,', ' ...]'])
+    last2 = p.rsplit("\n", 2)[-2:]
+    assert_equal(last2, [" 999,", " ...]"])
 
 
 def test_long_set():
     s = set(range(10000))
     p = pretty.pretty(s)
-    last2 = p.rsplit('\n', 2)[-2:]
-    assert_equal(last2, [' 999,', ' ...}'])
+    last2 = p.rsplit("\n", 2)[-2:]
+    assert_equal(last2, [" 999,", " ...}"])
 
 
 def test_long_tuple():
     tup = tuple(range(10000))
     p = pretty.pretty(tup)
-    last2 = p.rsplit('\n', 2)[-2:]
-    assert_equal(last2, [' 999,', ' ...)'])
+    last2 = p.rsplit("\n", 2)[-2:]
+    assert_equal(last2, [" 999,", " ...)"])
 
 
 def test_long_dict():
-    d = dict((n, n) for n in range(10000))
+    d = {n: n for n in range(10000)}
     p = pretty.pretty(d)
-    last2 = p.rsplit('\n', 2)[-2:]
-    assert_equal(last2, [' 999: 999,', ' ...}'])
+    last2 = p.rsplit("\n", 2)[-2:]
+    assert_equal(last2, [" 999: 999,", " ...}"])
 
 
 def test_unbound_method():
     output = pretty.pretty(MyObj.somemethod)
-    assert_in('MyObj.somemethod', output)
+    assert_in("MyObj.somemethod", output)
 
 
 class MetaClass(type):
-
     def __new__(cls, name):
-        return type.__new__(cls, name, (object,), {'name': name})
+        return type.__new__(cls, name, (object,), {"name": name})
 
     def __repr__(self):
-        return '[CUSTOM REPR FOR CLASS %s]' % self.name
+        return "[CUSTOM REPR FOR CLASS %s]" % self.name
 
 
-ClassWithMeta = MetaClass('ClassWithMeta')
+ClassWithMeta = MetaClass("ClassWithMeta")
 
 
 def test_metaclass_repr():
     output = pretty.pretty(ClassWithMeta)
-    assert_equal(output, '[CUSTOM REPR FOR CLASS ClassWithMeta]')
+    assert_equal(output, "[CUSTOM REPR FOR CLASS ClassWithMeta]")
 
 
 def test_unicode_repr():
@@ -416,7 +421,6 @@ def test_unicode_repr():
     ustr = unicode_to_str(u)
 
     class C(object):
-
         def __repr__(self):
             return ustr
 
@@ -424,7 +428,7 @@ def test_unicode_repr():
     p = pretty.pretty(c)
     assert_equal(p, u)
     p = pretty.pretty([c])
-    assert_equal(p, u'[%s]' % u)
+    assert_equal(p, u"[%s]" % u)
 
 
 def test_basic_class():
@@ -432,6 +436,7 @@ def test_basic_class():
         if obj is MyObj:
             type_pprint_wrapper.called = True
         return pretty._type_pprint(obj, p, cycle)
+
     type_pprint_wrapper.called = False
 
     stream = StringIO()
@@ -441,7 +446,7 @@ def test_basic_class():
     printer.flush()
     output = stream.getvalue()
 
-    assert_equal(output, '%s.MyObj' % __name__)
+    assert_equal(output, "%s.MyObj" % __name__)
     assert_true(type_pprint_wrapper.called)
 
 
@@ -466,11 +471,11 @@ def test_fallback_to__name__on_type():
     output = stream.getvalue()
 
     # If __qualname__ is malformed, we should fall back to __name__.
-    expected = '.'.join([__name__, Type.__name__])
+    expected = ".".join([__name__, Type.__name__])
     assert_equal(output, expected)
 
     # Clear stream buffer.
-    stream.buf = ''
+    stream.buf = ""
 
     # Test repring of an instance of the type.
     instance = Type()
@@ -480,7 +485,7 @@ def test_fallback_to__name__on_type():
 
     # Should look like:
     # <IPython.lib.tests.test_pretty.Type at 0x7f7658ae07d0>
-    prefix = '<' + '.'.join([__name__, Type.__name__]) + ' at 0x'
+    prefix = "<" + ".".join([__name__, Type.__name__]) + " at 0x"
     assert_true(output.startswith(prefix))
 
 
@@ -504,11 +509,11 @@ def test_fail_gracefully_on_bogus__qualname__and__name__():
     output = stream.getvalue()
 
     # If we can't find __name__ or __qualname__ just use a sentinel string.
-    expected = '.'.join([__name__, '<unknown type>'])
+    expected = ".".join([__name__, "<unknown type>"])
     assert_equal(output, expected)
 
     # Clear stream buffer.
-    stream.buf = ''
+    stream.buf = ""
 
     # Test repring of an instance of the type.
     instance = Type()
@@ -518,7 +523,7 @@ def test_fail_gracefully_on_bogus__qualname__and__name__():
 
     # Should look like:
     # <IPython.lib.tests.test_pretty.<unknown type> at 0x7f7658ae07d0>
-    prefix = '<' + '.'.join([__name__, '<unknown type>']) + ' at 0x'
+    prefix = "<" + ".".join([__name__, "<unknown type>"]) + " at 0x"
     assert_true(output.startswith(prefix))
 
 
@@ -527,40 +532,45 @@ def test_collections_defaultdict():
     a = defaultdict()
     a.default_factory = a
     b = defaultdict(list)
-    b['key'] = b
+    b["key"] = b
 
     # Dictionary order cannot be relied on, test against single keys.
     cases = [
-        (defaultdict(list), 'defaultdict(list, {})'),
-        (defaultdict(list, {'key': '-' * 50}),
-         'defaultdict(list,\n'
-         "            {'key': '-----------------------------------------"
-         "---------'})"),
-        (a, 'defaultdict(defaultdict(...), {})'),
+        (defaultdict(list), "defaultdict(list, {})"),
+        (
+            defaultdict(list, {"key": "-" * 50}),
+            "defaultdict(list,\n"
+            "            {'key': '-----------------------------------------"
+            "---------'})",
+        ),
+        (a, "defaultdict(defaultdict(...), {})"),
         (b, "defaultdict(list, {'key': defaultdict(...)})"),
     ]
     for obj, expected in cases:
         assert_equal(pretty.pretty(obj), expected)
 
 
+@pytest.mark.skipif(PY3 and PYPY, reason="slightly different on PyPy3")
 def test_collections_ordereddict():
     # Create OrderedDict with cycle
     a = OrderedDict()
-    a['key'] = a
+    a["key"] = a
 
     cases = [
-        (OrderedDict(), 'OrderedDict()'),
-        (OrderedDict((i, i) for i in range(1000, 1010)),
-         'OrderedDict([(1000, 1000),\n'
-         '             (1001, 1001),\n'
-         '             (1002, 1002),\n'
-         '             (1003, 1003),\n'
-         '             (1004, 1004),\n'
-         '             (1005, 1005),\n'
-         '             (1006, 1006),\n'
-         '             (1007, 1007),\n'
-         '             (1008, 1008),\n'
-         '             (1009, 1009)])'),
+        (OrderedDict(), "OrderedDict()"),
+        (
+            OrderedDict((i, i) for i in range(1000, 1010)),
+            "OrderedDict([(1000, 1000),\n"
+            "             (1001, 1001),\n"
+            "             (1002, 1002),\n"
+            "             (1003, 1003),\n"
+            "             (1004, 1004),\n"
+            "             (1005, 1005),\n"
+            "             (1006, 1006),\n"
+            "             (1007, 1007),\n"
+            "             (1008, 1008),\n"
+            "             (1009, 1009)])",
+        ),
         (a, "OrderedDict([('key', OrderedDict(...))])"),
     ]
     for obj, expected in cases:
@@ -573,29 +583,31 @@ def test_collections_deque():
     a.append(a)
 
     cases = [
-        (deque(), 'deque([])'),
-        (deque(i for i in range(1000, 1020)),
-         'deque([1000,\n'
-         '       1001,\n'
-         '       1002,\n'
-         '       1003,\n'
-         '       1004,\n'
-         '       1005,\n'
-         '       1006,\n'
-         '       1007,\n'
-         '       1008,\n'
-         '       1009,\n'
-         '       1010,\n'
-         '       1011,\n'
-         '       1012,\n'
-         '       1013,\n'
-         '       1014,\n'
-         '       1015,\n'
-         '       1016,\n'
-         '       1017,\n'
-         '       1018,\n'
-         '       1019])'),
-        (a, 'deque([deque(...)])'),
+        (deque(), "deque([])"),
+        (
+            deque(i for i in range(1000, 1020)),
+            "deque([1000,\n"
+            "       1001,\n"
+            "       1002,\n"
+            "       1003,\n"
+            "       1004,\n"
+            "       1005,\n"
+            "       1006,\n"
+            "       1007,\n"
+            "       1008,\n"
+            "       1009,\n"
+            "       1010,\n"
+            "       1011,\n"
+            "       1012,\n"
+            "       1013,\n"
+            "       1014,\n"
+            "       1015,\n"
+            "       1016,\n"
+            "       1017,\n"
+            "       1018,\n"
+            "       1019])",
+        ),
+        (a, "deque([deque(...)])"),
     ]
     for obj, expected in cases:
         assert_equal(pretty.pretty(obj), expected)
@@ -604,8 +616,9 @@ def test_collections_deque():
 def test_collections_counter():
     class MyCounter(Counter):
         pass
+
     cases = [
-        (Counter(), 'Counter()'),
+        (Counter(), "Counter()"),
         (Counter(a=1), "Counter({'a': 1})"),
         (MyCounter(a=1), "MyCounter({'a': 1})"),
     ]
@@ -616,17 +629,16 @@ def test_collections_counter():
 def test_cyclic_list():
     x = []
     x.append(x)
-    assert pretty.pretty(x) == '[[...]]'
+    assert pretty.pretty(x) == "[[...]]"
 
 
 def test_cyclic_dequeue():
     x = deque()
     x.append(x)
-    assert pretty.pretty(x) == 'deque([deque(...)])'
+    assert pretty.pretty(x) == "deque([deque(...)])"
 
 
 class HashItAnyway(object):
-
     def __init__(self, value):
         self.value = value
 
@@ -647,40 +659,39 @@ def test_cyclic_counter():
     c = Counter()
     k = HashItAnyway(c)
     c[k] = 1
-    assert pretty.pretty(c) == 'Counter({Counter(...): 1})'
+    assert pretty.pretty(c) == "Counter({Counter(...): 1})"
 
 
 def test_cyclic_dict():
     x = {}
     k = HashItAnyway(x)
     x[k] = x
-    assert pretty.pretty(x) == '{{...}: {...}}'
+    assert pretty.pretty(x) == "{{...}: {...}}"
 
 
 def test_cyclic_set():
     x = set()
     x.add(HashItAnyway(x))
-    assert pretty.pretty(x) == '{{...}}'
+    assert pretty.pretty(x) == "{{...}}"
 
 
 def test_pprint():
-    t = {'hi': 1}
+    t = {"hi": 1}
     with capture_out() as o:
         pretty.pprint(t)
     assert o.getvalue().strip() == pretty.pretty(t)
 
 
 class BigList(list):
-
     def _repr_pretty_(self, printer, cycle):
         if cycle:
-            return '[...]'
+            return "[...]"
         else:
-            with printer.group(open='[', close=']'):
+            with printer.group(open="[", close="]"):
                 with printer.indent(5):
                     for v in self:
                         printer.pretty(v)
-                        printer.breakable(',')
+                        printer.breakable(",")
 
 
 def test_print_with_indent():
@@ -692,63 +703,60 @@ class MyException(Exception):
 
 
 def test_exception():
-    assert pretty.pretty(ValueError('hi')) == "ValueError('hi')"
-    assert pretty.pretty(ValueError('hi', 'there')) == \
-        "ValueError('hi', 'there')"
-    assert 'test_pretty.' in pretty.pretty(MyException())
+    assert pretty.pretty(ValueError("hi")) == "ValueError('hi')"
+    assert pretty.pretty(ValueError("hi", "there")) == "ValueError('hi', 'there')"
+    assert "test_pretty." in pretty.pretty(MyException())
 
 
 def test_re_evals():
     for r in [
-        re.compile(r'hi'), re.compile(r'b\nc', re.MULTILINE),
-        re.compile(br'hi', 0), re.compile(u'foo', re.MULTILINE | re.UNICODE),
+        re.compile(r"hi"),
+        re.compile(r"b\nc", re.MULTILINE),
+        re.compile(br"hi", 0),
+        re.compile(u"foo", re.MULTILINE | re.UNICODE),
     ]:
         r2 = eval(pretty.pretty(r), globals())
         assert r.pattern == r2.pattern and r.flags == r2.flags
 
 
 class CustomStuff(object):
-
     def __init__(self):
         self.hi = 1
-        self.bye = 'fish'
+        self.bye = "fish"
         self.spoon = self
 
     @property
     def oops(self):
-        raise AttributeError('Nope')
+        raise AttributeError("Nope")
 
     def squirrels(self):
         pass
 
 
 def test_custom():
-    assert 'bye' not in pretty.pretty(CustomStuff())
-    assert 'bye=' in pretty.pretty(CustomStuff(), verbose=True)
-    assert 'squirrels' not in pretty.pretty(CustomStuff(), verbose=True)
+    assert "bye" not in pretty.pretty(CustomStuff())
+    assert "bye=" in pretty.pretty(CustomStuff(), verbose=True)
+    assert "squirrels" not in pretty.pretty(CustomStuff(), verbose=True)
 
 
 def test_print_builtin_function():
-    assert pretty.pretty(abs) == '<function abs>'
+    assert pretty.pretty(abs) == "<function abs>"
 
 
 def test_pretty_function():
-    assert '.' in pretty.pretty(test_pretty_function)
+    assert "." in pretty.pretty(test_pretty_function)
 
 
 def test_empty_printer():
     printer = pretty.RepresentationPrinter(
         pretty.CUnicodeIO(),
         singleton_pprinters={},
-        type_pprinters={
-            int: pretty._repr_pprint,
-            list: pretty._repr_pprint,
-        },
+        type_pprinters={int: pretty._repr_pprint, list: pretty._repr_pprint},
         deferred_pprinters={},
     )
     printer.pretty([1, 2, 3])
-    assert printer.output.getvalue() == u'[1, 2, 3]'
+    assert printer.output.getvalue() == u"[1, 2, 3]"
 
 
 def test_breakable_at_group_boundary():
-    assert '\n' in pretty.pretty([[], '000000'], max_width=5)
+    assert "\n" in pretty.pretty([[], "000000"], max_width=5)
