@@ -1,9 +1,9 @@
 # coding=utf-8
 #
 # This file is part of Hypothesis, which may be found at
-# https://github.com/HypothesisWorks/hypothesis-python
+# https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2018 David R. MacIver
+# Most of this work is copyright (C) 2013-2019 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -11,19 +11,20 @@
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
-# obtain one at http://mozilla.org/MPL/2.0/.
+# obtain one at https://mozilla.org/MPL/2.0/.
 #
 # END HEADER
 
-from __future__ import division, print_function, absolute_import
+from __future__ import absolute_import, division, print_function
 
 import pytest
 
 import hypothesis.strategies as st
-from hypothesis import given, settings
-from hypothesis.errors import Flaky, MultipleFailures
-from tests.common.utils import capture_out, non_covering_examples
+from hypothesis import Phase, assume, given, settings
 from hypothesis.database import InMemoryExampleDatabase
+from hypothesis.errors import Flaky, MultipleFailures
+from hypothesis.internal.conjecture.engine import MIN_TEST_CALLS
+from tests.common.utils import capture_out, flaky, non_covering_examples
 
 
 def test_raises_multiple_failures_with_varying_type():
@@ -35,6 +36,9 @@ def test_raises_multiple_failures_with_varying_type():
         if abs(i) < 1000:
             return
         if target[0] is None:
+            # Ensure that we have some space to shrink into, so we can't
+            # trigger an minimal example and mask the other exception type.
+            assume(1003 < abs(i))
             target[0] = i
         exc_class = TypeError if target[0] == i else ValueError
         raise exc_class()
@@ -43,8 +47,8 @@ def test_raises_multiple_failures_with_varying_type():
         with pytest.raises(MultipleFailures):
             test()
 
-    assert 'TypeError' in o.getvalue()
-    assert 'ValueError' in o.getvalue()
+    assert "TypeError" in o.getvalue()
+    assert "ValueError" in o.getvalue()
 
 
 def test_raises_multiple_failures_when_position_varies():
@@ -57,15 +61,15 @@ def test_raises_multiple_failures_when_position_varies():
         if target[0] is None:
             target[0] = i
         if target[0] == i:
-            raise ValueError('loc 1')
+            raise ValueError("loc 1")
         else:
-            raise ValueError('loc 2')
+            raise ValueError("loc 2")
 
     with capture_out() as o:
         with pytest.raises(MultipleFailures):
             test()
-    assert 'loc 1' in o.getvalue()
-    assert 'loc 2' in o.getvalue()
+    assert "loc 1" in o.getvalue()
+    assert "loc 2" in o.getvalue()
 
 
 def test_replays_both_failing_values():
@@ -88,7 +92,7 @@ def test_replays_both_failing_values():
         test()
 
 
-@pytest.mark.parametrize('fix', [TypeError, ValueError])
+@pytest.mark.parametrize("fix", [TypeError, ValueError])
 def test_replays_slipped_examples_once_initial_bug_is_fixed(fix):
     target = []
     bug_fixed = False
@@ -163,8 +167,8 @@ def test_shrinks_both_failures():
     duds = set()
     second_target = [None]
 
-    @settings(database=None)
-    @given(st.integers(min_value=0))
+    @settings(database=None, max_examples=1000)
+    @given(st.integers(min_value=0).map(int))
     def test(i):
         if i >= 10000:
             first_has_failed[0] = True
@@ -184,8 +188,8 @@ def test_shrinks_both_failures():
         with pytest.raises(MultipleFailures):
             test()
 
-    assert 'test(i=10000)' in o.getvalue()
-    assert 'test(i=%d)' % (second_target[0],) in o.getvalue()
+    assert "test(i=10000)" in o.getvalue()
+    assert "test(i=%d)" % (second_target[0],) in o.getvalue()
 
 
 def test_handles_flaky_tests_where_only_one_is_flaky():
@@ -218,3 +222,75 @@ def test_handles_flaky_tests_where_only_one_is_flaky():
 
     with pytest.raises(MultipleFailures):
         test()
+
+
+@pytest.mark.parametrize("allow_multi", [True, False])
+def test_can_disable_multiple_error_reporting(allow_multi):
+    seen = set()
+
+    @settings(database=None, derandomize=True, report_multiple_bugs=allow_multi)
+    @given(st.integers(min_value=0))
+    def test(i):
+        # We will pass on the minimal i=0, then fail with a large i, and eventually
+        # slip to i=1 and a different error.  We check both seen and raised errors.
+        if i == 1:
+            seen.add(TypeError)
+            raise TypeError
+        elif i >= 2:
+            seen.add(ValueError)
+            raise ValueError
+
+    with pytest.raises(MultipleFailures if allow_multi else TypeError):
+        test()
+    assert seen == {TypeError, ValueError}
+
+
+@flaky(max_runs=3, min_passes=2)
+def test_finds_multiple_failures_in_generation():
+    # Very rarely, this raises ZeroDivisionError instead of MultipleFailure,
+    # because we never generated NaN.  We therefore allow one additional run.
+    @settings(phases=[Phase.generate])
+    @given(st.lists(st.floats()))
+    def test(x):
+        mean = sum(x) / len(x)  # ZeroDivisionError
+        if len(x) == 1:
+            assert mean == x[0]  # x[0] is nan
+        assert min(x) <= mean <= max(x)  # x contains nan or +&- inf
+
+    with pytest.raises(MultipleFailures):
+        test()
+
+
+def test_stops_immediately_if_not_report_multiple_bugs():
+    seen = set()
+
+    @settings(phases=[Phase.generate], report_multiple_bugs=False)
+    @given(st.integers())
+    def test(x):
+        seen.add(x)
+        assert False
+
+    with pytest.raises(AssertionError):
+        test()
+    assert len(seen) == 1
+
+
+def test_stops_immediately_on_replay():
+    seen = set()
+
+    @settings(database=InMemoryExampleDatabase())
+    @given(st.integers())
+    def test(x):
+        seen.add(x)
+        assert x
+
+    # On the first run, we look for up to ten examples:
+    with pytest.raises(AssertionError):
+        test()
+    assert 1 < len(seen) <= MIN_TEST_CALLS
+
+    # With failing examples in the database, we stop at one.
+    seen.clear()
+    with pytest.raises(AssertionError):
+        test()
+    assert len(seen) == 1
