@@ -1,9 +1,9 @@
 # coding=utf-8
 #
 # This file is part of Hypothesis, which may be found at
-# https://github.com/HypothesisWorks/hypothesis-python
+# https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2018 David R. MacIver
+# Most of this work is copyright (C) 2013-2019 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -11,11 +11,11 @@
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
-# obtain one at http://mozilla.org/MPL/2.0/.
+# obtain one at https://mozilla.org/MPL/2.0/.
 #
 # END HEADER
 
-from __future__ import division, print_function, absolute_import
+from __future__ import absolute_import, division, print_function
 
 from collections import Counter
 
@@ -33,7 +33,7 @@ class Blocks(SearchStrategy):
         return data.draw_bytes(self.n)
 
 
-@pytest.mark.parametrize('n', range(1, 5))
+@pytest.mark.parametrize("n", range(1, 5))
 def test_does_not_duplicate_blocks(n):
     counts = Counter()
 
@@ -41,11 +41,12 @@ def test_does_not_duplicate_blocks(n):
     @settings(database=None)
     def test(b):
         counts[b] += 1
+
     test()
     assert set(counts.values()) == {1}
 
 
-@pytest.mark.parametrize('n', range(1, 5))
+@pytest.mark.parametrize("n", range(1, 5))
 def test_mostly_does_not_duplicate_blocks_even_when_failing(n):
     counts = Counter()
 
@@ -55,6 +56,7 @@ def test_mostly_does_not_duplicate_blocks_even_when_failing(n):
         counts[b] += 1
         if len(counts) > 3:
             raise ValueError()
+
     try:
         test()
     except ValueError:
