@@ -1,9 +1,9 @@
 # coding=utf-8
 #
 # This file is part of Hypothesis, which may be found at
-# https://github.com/HypothesisWorks/hypothesis-python
+# https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2018 David R. MacIver
+# Most of this work is copyright (C) 2013-2019 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -11,20 +11,21 @@
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
-# obtain one at http://mozilla.org/MPL/2.0/.
+# obtain one at https://mozilla.org/MPL/2.0/.
 #
 # END HEADER
 
-from __future__ import division, print_function, absolute_import
+from __future__ import absolute_import, division, print_function
 
-import sys
 import math
+import sys
 
 import pytest
 
 from hypothesis import given
+from hypothesis.strategies import floats, integers, lists
 from tests.common.debug import minimal
-from hypothesis.strategies import lists, floats, integers
+from tests.common.utils import checks_deprecated_behaviour
 
 
 def test_minimize_negative_int():
@@ -37,12 +38,15 @@ def test_positive_negative_int():
     assert minimal(integers(), lambda x: x > 1) == 2
 
 
-boundaries = pytest.mark.parametrize(u'boundary', sorted(
-    [2 ** i for i in range(10)] +
-    [2 ** i - 1 for i in range(10)] +
-    [2 ** i + 1 for i in range(10)] +
-    [10 ** i for i in range(6)]
-))
+boundaries = pytest.mark.parametrize(
+    u"boundary",
+    sorted(
+        [2 ** i for i in range(10)]
+        + [2 ** i - 1 for i in range(10)]
+        + [2 ** i + 1 for i in range(10)]
+        + [10 ** i for i in range(6)]
+    ),
+)
 
 
 @boundaries
@@ -61,8 +65,7 @@ def test_minimizes_ints_from_down_to_boundary(boundary):
         assert x >= boundary - 10
         return x >= boundary
 
-    assert minimal(
-        integers(min_value=boundary - 10), is_good) == boundary
+    assert minimal(integers(min_value=boundary - 10), is_good) == boundary
 
     assert minimal(integers(min_value=boundary), lambda x: True) == boundary
 
@@ -73,9 +76,7 @@ def test_minimizes_negative_integer_range_upwards():
 
 @boundaries
 def test_minimizes_integer_range_to_boundary(boundary):
-    assert minimal(
-        integers(boundary, boundary + 100), lambda x: True
-    ) == boundary
+    assert minimal(integers(boundary, boundary + 100), lambda x: True) == boundary
 
 
 def test_single_integer_range_is_range():
@@ -83,15 +84,11 @@ def test_single_integer_range_is_range():
 
 
 def test_minimal_small_number_in_large_range():
-    assert minimal(
-        integers((-2 ** 32), 2 ** 32), lambda x: x >= 101) == 101
+    assert minimal(integers((-2 ** 32), 2 ** 32), lambda x: x >= 101) == 101
 
 
 def test_minimal_small_sum_float_list():
-    xs = minimal(
-        lists(floats(), min_size=10),
-        lambda x: sum(x) >= 1.0
-    )
+    xs = minimal(lists(floats(), min_size=10), lambda x: sum(x) >= 1.0)
     assert sum(xs) <= 2.0
 
 
@@ -99,6 +96,7 @@ def test_minimals_boundary_floats():
     def f(x):
         print(x)
         return True
+
     assert -1 <= minimal(floats(min_value=-1, max_value=1), f) <= 1
 
 
@@ -116,7 +114,7 @@ def test_negative_floats_simplify_to_zero():
 
 
 def test_minimal_infinite_float_is_positive():
-    assert minimal(floats(), math.isinf) == float(u'inf')
+    assert minimal(floats(), math.isinf) == float(u"inf")
 
 
 def test_can_minimal_infinite_negative_float():
@@ -133,7 +131,7 @@ def test_minimize_nan():
 
 def test_minimize_very_large_float():
     t = sys.float_info.max / 2
-    assert t <= minimal(floats(), lambda x: x >= t) < float(u'inf')
+    assert t <= minimal(floats(), lambda x: x >= t) < float(u"inf")
 
 
 def is_integral(value):
@@ -144,19 +142,20 @@ def is_integral(value):
 
 
 def test_can_minimal_float_far_from_integral():
-    minimal(floats(), lambda x: not (
-        math.isnan(x) or
-        math.isinf(x) or
-        is_integral(x * (2 ** 32))
-    ))
+    minimal(
+        floats(),
+        lambda x: not (math.isnan(x) or math.isinf(x) or is_integral(x * (2 ** 32))),
+    )
 
 
 def test_list_of_fractional_float():
-    assert set(minimal(
-        lists(floats(), min_size=5),
-        lambda x: len([t for t in x if t >= 1.5]) >= 5,
-        timeout_after=60,
-    )).issubset([1.5, 2.0])
+    assert set(
+        minimal(
+            lists(floats(), min_size=5),
+            lambda x: len([t for t in x if t >= 1.5]) >= 5,
+            timeout_after=60,
+        )
+    ).issubset([1.5, 2.0])
 
 
 def test_minimal_fractional_float():
@@ -166,20 +165,21 @@ def test_minimal_fractional_float():
 def test_minimizes_lists_of_negative_ints_up_to_boundary():
     result = minimal(
         lists(integers(), min_size=10),
-        lambda x: len([t for t in x if t <= -1]) >= 10, timeout_after=60)
+        lambda x: len([t for t in x if t <= -1]) >= 10,
+        timeout_after=60,
+    )
     assert result == [-1] * 10
 
 
-@pytest.mark.parametrize((u'left', u'right'), [
-    (0.0, 5e-324),
-    (-5e-324, 0.0),
-    (-5e-324, 5e-324),
-    (5e-324, 1e-323),
-])
+@pytest.mark.parametrize(
+    (u"left", u"right"),
+    [(0.0, 5e-324), (-5e-324, 0.0), (-5e-324, 5e-324), (5e-324, 1e-323)],
+)
 def test_floats_in_constrained_range(left, right):
     @given(floats(left, right))
     def test_in_range(r):
         assert left <= r <= right
+
     test_in_range()
 
 
@@ -188,7 +188,7 @@ def test_bounds_are_respected():
     assert minimal(floats(max_value=-1.0), lambda x: True) == -1.0
 
 
-@pytest.mark.parametrize('k', range(10))
+@pytest.mark.parametrize("k", range(10))
 def test_floats_from_zero_have_reasonable_range(k):
     n = 10 ** k
     assert minimal(floats(min_value=0.0), lambda x: x >= n) == float(n)
@@ -215,11 +215,11 @@ def test_no_allow_infinity_lower(x):
 
 
 class TestFloatsAreFloats(object):
-
     @given(floats())
     def test_unbounded(self, arg):
         assert isinstance(arg, float)
 
+    @checks_deprecated_behaviour
     @given(floats(min_value=0, max_value=2 ** 64 - 1))
     def test_int_int(self, arg):
         assert isinstance(arg, float)
@@ -228,6 +228,7 @@ class TestFloatsAreFloats(object):
     def test_int_float(self, arg):
         assert isinstance(arg, float)
 
+    @checks_deprecated_behaviour
     @given(floats(min_value=float(0), max_value=2 ** 64 - 1))
     def test_float_int(self, arg):
         assert isinstance(arg, float)
