@@ -1,9 +1,9 @@
 # coding=utf-8
 #
 # This file is part of Hypothesis, which may be found at
-# https://github.com/HypothesisWorks/hypothesis-python
+# https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2018 David R. MacIver
+# Most of this work is copyright (C) 2013-2019 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -11,23 +11,25 @@
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
-# obtain one at http://mozilla.org/MPL/2.0/.
+# obtain one at https://mozilla.org/MPL/2.0/.
 #
 # END HEADER
 
-from __future__ import division, print_function, absolute_import
+from __future__ import absolute_import, division, print_function
 
-pytest_plugins = 'pytester'
+pytest_plugins = "pytester"
+
+func_with_doctest = """
+def hi():
+    '''
+    >>> i = 5
+    >>> i-1
+    4
+    '''
+"""
 
 
 def test_can_run_doctests(testdir):
-    script = testdir.makepyfile(
-        'def hi():\n'
-        '    """\n'
-        '    >>> i = 5\n'
-        '    >>> i-1\n'
-        '    4"""'
-    )
-
-    result = testdir.runpytest(script, '--doctest-modules')
+    script = testdir.makepyfile(func_with_doctest)
+    result = testdir.runpytest(script, "--doctest-modules")
     assert result.ret == 0
