@@ -1,9 +1,9 @@
 # coding=utf-8
 #
 # This file is part of Hypothesis, which may be found at
-# https://github.com/HypothesisWorks/hypothesis-python
+# https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2018 David R. MacIver
+# Most of this work is copyright (C) 2013-2019 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -11,16 +11,16 @@
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
-# obtain one at http://mozilla.org/MPL/2.0/.
+# obtain one at https://mozilla.org/MPL/2.0/.
 #
 # END HEADER
 
-from __future__ import division, print_function, absolute_import
+from __future__ import absolute_import, division, print_function
 
-from hypothesis.version import __version__
 from hypothesis.extra.pytestplugin import LOAD_PROFILE_OPTION
+from hypothesis.version import __version__
 
-pytest_plugins = str('pytester')
+pytest_plugins = str("pytester")
 
 CONFTEST = """
 from hypothesis._settings import settings
@@ -40,8 +40,8 @@ def test_this_one_is_ok():
 def test_runs_reporting_hook(testdir):
     script = testdir.makepyfile(TESTSUITE)
     testdir.makeconftest(CONFTEST)
-    result = testdir.runpytest(script, LOAD_PROFILE_OPTION, 'test')
-    out = '\n'.join(result.stdout.lines)
-    assert '1 passed' in out
-    assert 'max_examples=1' in out
+    result = testdir.runpytest(script, LOAD_PROFILE_OPTION, "test")
+    out = "\n".join(result.stdout.lines)
+    assert "1 passed" in out
+    assert "max_examples=1" in out
     assert __version__ in out
