@@ -1,9 +1,9 @@
 # coding=utf-8
 #
 # This file is part of Hypothesis, which may be found at
-# https://github.com/HypothesisWorks/hypothesis-python
+# https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2018 David R. MacIver
+# Most of this work is copyright (C) 2013-2019 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -11,13 +11,13 @@
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
-# obtain one at http://mozilla.org/MPL/2.0/.
+# obtain one at https://mozilla.org/MPL/2.0/.
 #
 # END HEADER
 
-from __future__ import division, print_function, absolute_import
+from __future__ import absolute_import, division, print_function
 
-pytest_plugins = str('pytester')
+pytest_plugins = str("pytester")
 
 
 TESTSUITE = """
@@ -36,9 +36,9 @@ def test_hi(xs):
 
 def test_runs_reporting_hook(testdir):
     script = testdir.makepyfile(TESTSUITE)
-    result = testdir.runpytest(script, '--verbose')
-    out = '\n'.join(result.stdout.lines)
-    assert 'test_this_one_is_ok' in out
-    assert 'Captured stdout call' not in out
-    assert 'Falsifying example' in out
+    result = testdir.runpytest(script, "--verbose")
+    out = "\n".join(result.stdout.lines)
+    assert "test_this_one_is_ok" in out
+    assert "Captured stdout call" not in out
+    assert "Falsifying example" in out
     assert result.ret != 0
