@@ -1,9 +1,9 @@
 # coding=utf-8
 #
 # This file is part of Hypothesis, which may be found at
-# https://github.com/HypothesisWorks/hypothesis-python
+# https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2018 David R. MacIver
+# Most of this work is copyright (C) 2013-2019 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -11,24 +11,27 @@
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
-# obtain one at http://mozilla.org/MPL/2.0/.
+# obtain one at https://mozilla.org/MPL/2.0/.
 #
 # END HEADER
 
-from __future__ import division, print_function, absolute_import
+from __future__ import absolute_import, division, print_function
 
 from random import Random
 
 import pytest
 
 import hypothesis.internal.conjecture.utils as cu
-from hypothesis import HealthCheck, settings, unlimited
-from hypothesis.searchstrategy import SearchStrategy
+from hypothesis import HealthCheck, settings
 from hypothesis.internal.compat import hbytes, hrange
-from hypothesis.internal.conjecture.engine import ConjectureData, \
-    ConjectureRunner, uniform
+from hypothesis.internal.conjecture.engine import (
+    ConjectureData,
+    ConjectureRunner,
+    uniform,
+)
+from hypothesis.searchstrategy import SearchStrategy
 
-POISON = 'POISON'
+POISON = "POISON"
 
 MAX_INT = 2 ** 32 - 1
 
@@ -63,13 +66,15 @@ LOTS = 10 ** 6
 
 
 TEST_SETTINGS = settings(
-    database=None, suppress_health_check=HealthCheck.all(), max_examples=LOTS,
-    deadline=None, timeout=unlimited
+    database=None,
+    suppress_health_check=HealthCheck.all(),
+    max_examples=LOTS,
+    deadline=None,
 )
 
 
-@pytest.mark.parametrize('size', [2, 5, 10])
-@pytest.mark.parametrize('seed', [0, 15993493061449915028])
+@pytest.mark.parametrize("size", [2, 5, 10])
+@pytest.mark.parametrize("seed", [0, 15993493061449915028])
 def test_can_reduce_poison_from_any_subtree(size, seed):
     """This test validates that we can minimize to any leaf node of a binary
     tree, regardless of where in the tree the leaf is."""
@@ -89,14 +94,12 @@ def test_can_reduce_poison_from_any_subtree(size, seed):
         if len(v) >= size:
             data.mark_interesting()
 
-    runner = ConjectureRunner(
-        test_function, random=random, settings=TEST_SETTINGS
-    )
+    runner = ConjectureRunner(test_function, random=random, settings=TEST_SETTINGS)
 
     while not runner.interesting_examples:
-        runner.test_function(ConjectureData(
-            draw_bytes=lambda data, n: uniform(random, n),
-            max_length=LOTS))
+        runner.test_function(
+            runner.new_conjecture_data(lambda data, n: uniform(random, n))
+        )
 
     runner.shrink_interesting_examples()
 
@@ -104,7 +107,7 @@ def test_can_reduce_poison_from_any_subtree(size, seed):
 
     assert len(ConjectureData.for_buffer(data.buffer).draw(strat)) == size
 
-    starts = data.block_starts[2]
+    starts = [b.start for b in data.blocks if b.length == 2]
     assert len(starts) % 2 == 0
 
     for i in hrange(0, len(starts), 2):
@@ -115,24 +118,23 @@ def test_can_reduce_poison_from_any_subtree(size, seed):
         u = starts[i]
         marker = hbytes([1, 2, 3, 4])
 
-        poisoned_data = ConjectureData.for_buffer(
-            data.buffer[:u] + hbytes([255]) * 4 + data.buffer[u + 4:] +
-            marker
-        )
-
-        def test_function(data):
+        def test_function_with_poison(data):
             v = data.draw(strat)
             m = data.draw_bytes(len(marker))
             if POISON in v and m == marker:
                 data.mark_interesting()
-        runner = ConjectureRunner(
-            test_function, random=random, settings=TEST_SETTINGS)
 
-        runner.test_function(poisoned_data)
+        runner = ConjectureRunner(
+            test_function_with_poison, random=random, settings=TEST_SETTINGS
+        )
+
+        runner.cached_test_function(
+            data.buffer[:u] + hbytes([255]) * 4 + data.buffer[u + 4 :] + marker
+        )
+
         assert runner.interesting_examples
         runner.shrink_interesting_examples()
 
         shrunk, = runner.interesting_examples.values()
 
-        assert ConjectureData.for_buffer(
-            shrunk.buffer).draw(strat) == (POISON,)
+        assert ConjectureData.for_buffer(shrunk.buffer).draw(strat) == (POISON,)
